class Line {
  constructor(x0,y0,xf,yf) {
    this.x0 = x0;
    this.y0 = y0;
    this.xf = xf;
    this.yf = yf;
    this.width = Math.abs(xf - x0);
    this.height = Math.abs(yf - y0);
    if (this.x0 < this.xf)
      this.centerX = x0 + this.width/2;
    else 
      this.centerX = xf + this.width/2;
    if (this.y0 < this.yf)
      this.centerY = y0 + this.height/2;
    else 
      this.centerY = yf + this.height/2;
  }
}

var canvas = document.getElementById('canvas');
var ctx = canvas.getContext('2d');
var width = window.innerWidth;
var height = window.innerHeight;
var centerX = width / 2;
var centerY = height / 2;

var mouseX = 0;
var mouseY = 0;
var mouseDown = 0;
var rightClick = 0;

var lines = [];
lines[0] = new Line(centerX-200,centerY,centerX+200,centerY);
var selectedLine = null;
var movingEntireLine = false;
var draggingFirstEnd = false;
var draggingSecondEnd = false;

canvas.width = width;
canvas.height = height;
canvas.style.background = "#333";
document.body.style.color = "#fff";
ctx.strokeStyle = "#fff";

//event listeners
window.addEventListener('resize', resizeCanvas, false);
window.addEventListener('mousedown', handleMouseDown, false);
window.addEventListener('mouseup', handleMouseUp, false);
document.addEventListener("contextmenu", function(e){
    e.preventDefault();
}, false);
onmousemove = function(e){
  mouseX = e.clientX; 
  mouseY = e.clientY;
}

//event handlers 
function resizeCanvas() {
  canvas.width = window.innerWidth;
  canvas.height = window.innerHeight;
  width = window.innerWidth;
  height = window.innerHeight;
  centerX = width / 2;
  centerY = height / 2;
  drawCurrentCanvas();
}

function handleMouseDown(e) {
  rightClick = e.button == 2?1:0;
  if (!rightClick) mouseDown = 1;
}

function handleMouseUp() {
  mouseDown = 0;
  rightClick = 0;
  selectedLine = null;
  movingEntireLine = false;
  draggingFirstEnd = false;
  draggingSecondEnd = false;  
}

function dragLine() {
  if (selectedLine != null) {
    if (movingEntireLine) {      
      if (lines[selectedLine].x0 <= lines[selectedLine].xf) {
        lines[selectedLine].x0 = mouseX-(lines[selectedLine].width/2);
        lines[selectedLine].xf = mouseX+(lines[selectedLine].width/2);
      } else {
        lines[selectedLine].xf = mouseX-(lines[selectedLine].width/2);
        lines[selectedLine].x0 = mouseX+(lines[selectedLine].width/2);
      }
      if (lines[selectedLine].y0 <= lines[selectedLine].yf) {
        lines[selectedLine].y0 = mouseY-(lines[selectedLine].height/2);
        lines[selectedLine].yf = mouseY+(lines[selectedLine].height/2);
      } else {
        lines[selectedLine].yf = mouseY-(lines[selectedLine].height/2);
        lines[selectedLine].y0 = mouseY+(lines[selectedLine].height/2); 
      }
      if (lines[selectedLine].x0 <= lines[selectedLine].xf) {
        lines[selectedLine].centerX = lines[selectedLine].x0 + lines[selectedLine].width/2;
      } else {
        lines[selectedLine].centerX = lines[selectedLine].xf + lines[selectedLine].width/2;
      }
      if (lines[selectedLine].y0 <= lines[selectedLine].yf) {
        lines[selectedLine].centerY = lines[selectedLine].y0 + lines[selectedLine].height/2;
      } else {
        lines[selectedLine].centerY = lines[selectedLine].yf + lines[selectedLine].height/2;
      }
    } else if (draggingFirstEnd) {
      lines[selectedLine].x0 = mouseX;
      lines[selectedLine].y0 = mouseY;
      lines[selectedLine].width = Math.abs(lines[selectedLine].xf - lines[selectedLine].x0);
      lines[selectedLine].height = Math.abs(lines[selectedLine].yf - lines[selectedLine].y0);
      if (lines[selectedLine].x0 <= lines[selectedLine].xf) {
        lines[selectedLine].centerX = lines[selectedLine].x0 + lines[selectedLine].width/2;
      } else {
        lines[selectedLine].centerX = lines[selectedLine].xf + lines[selectedLine].width/2;
      }
      if (lines[selectedLine].y0 <= lines[selectedLine].yf) {
        lines[selectedLine].centerY = lines[selectedLine].y0 + lines[selectedLine].height/2;
      } else {
        lines[selectedLine].centerY = lines[selectedLine].yf + lines[selectedLine].height/2;
      }
    } else if (draggingSecondEnd) {
      lines[selectedLine].xf = mouseX;
      lines[selectedLine].yf = mouseY;
      lines[selectedLine].width = Math.abs(lines[selectedLine].xf - lines[selectedLine].x0);
      lines[selectedLine].height = Math.abs(lines[selectedLine].yf - lines[selectedLine].y0);
      if (lines[selectedLine].x0 <= lines[selectedLine].xf) {
        lines[selectedLine].centerX = lines[selectedLine].x0 + lines[selectedLine].width/2;
      } else {
        lines[selectedLine].centerX = lines[selectedLine].xf + lines[selectedLine].width/2;
      }
      if (lines[selectedLine].y0 <= lines[selectedLine].yf) {
        lines[selectedLine].centerY = lines[selectedLine].y0 + lines[selectedLine].height/2;
      } else {
        lines[selectedLine].centerY = lines[selectedLine].yf + lines[selectedLine].height/2;
      }
    }
  }
}

function handleMouse() {
  if (mouseDown && selectedLine == null) {
    for (var i = lines.length - 1; i >= 0; i--) {
      if (mouseX >= lines[i].centerX - 10 && mouseX <= lines[i].centerX + 10 && mouseY >= lines[i].centerY - 10 && mouseY <= lines[i].centerY + 10) {
        selectedLine = i;
        movingEntireLine = true;
        break;
      } else if (mouseX >= lines[i].x0 - 20 && mouseX <= lines[i].x0 + 20 && 
        mouseY >= lines[i].y0 - 20 && mouseY <= lines[i].y0 + 20) {
        selectedLine = i;
        draggingFirstEnd = true;
        break;
      } else if (mouseX >= lines[i].xf - 20 && mouseX <= lines[i].xf + 20 
        && mouseY >= lines[i].yf - 20 && mouseY <= lines[i].yf + 20) {
        selectedLine = i;
        draggingSecondEnd = true;
        break;
      }
    }
  } else if (rightClick) {
    for (var i = lines.length - 1; i >= 0; i--) {
      if ((mouseY >= lines[i].y0 && mouseY <= lines[i].yf) || (mouseY >= lines[i].yf && mouseY <= lines[i].y0)) {
        if (mouseX >= lines[i].x0 && mouseX <= lines[i].xf) {
          lines[lines.length] = new Line(mouseX,mouseY,lines[i].xf,lines[i].yf);
          lines[i].xf = mouseX;
          lines[i].yf = mouseY;
          lines[i].width = Math.abs(lines[i].xf - lines[i].x0);
          lines[i].height = Math.abs(lines[i].yf - lines[i].y0);
          lines[i].centerX = lines[i].x0 + lines[i].width/2;
          lines[i].centerY = lines[i].y0 + lines[i].height/2;      
          rightClick = 0;
          break;
        } else if (mouseX <= lines[i].x0 && mouseX >= lines[i].xf) {
          lines[lines.length] = new Line(mouseX,mouseY,lines[i].x0,lines[i].y0);
          lines[i].x0 = mouseX;
          lines[i].y0 = mouseY;
          lines[i].width = Math.abs(lines[i].xf - lines[i].x0);
          lines[i].height = Math.abs(lines[i].yf - lines[i].y0);
          lines[i].centerX = lines[i].xf + lines[i].width/2;
          lines[i].centerY = lines[i].yf + lines[i].height/2;       
          rightClick = 0;
          break;        
        }
      }
    }
  }
}

function generatePolygon() {
  edges = parseInt(document.getElementById("number").value,10);
  if (edges >= 3 && edges <= 8) {
    lines = [];
    var tmpx0 = centerX + 300;
    var tmpy0 = centerY;

    var edge = (2 * Math.PI)/edges;
    for (var i = 0; i < edges; i++) {
      var angle = edge * (i+1);
      var tmpxf = 300 * Math.cos(angle) + centerX;
      var tmpyf = 300 * Math.sin(angle) + centerY;
      lines[i] = new Line(tmpx0, tmpy0, tmpxf,tmpyf);
      tmpx0 = tmpxf;
      tmpy0 = tmpyf;
    }
    drawCurrentCanvas();
  } else {
    alert("Valor inválido! O número de arestas deve estar no intervalo de [3..8].")
  }
}

//function that updates screen
function drawCurrentCanvas() {
  drawLines();
  if ((mouseDown && selectedLine == null) || rightClick) handleMouse();
  dragLine();
  requestAnimationFrame(drawCurrentCanvas);
}

//function that draws all existing lines
function drawLines() {
  ctx.clearRect(0,0,canvas.width,canvas.height);
  for (var i = lines.length - 1; i >= 0; i--) {
    drawLine(lines[i].x0,lines[i].y0,lines[i].xf,lines[i].yf, i);
  }
}

//function that draws a line
function drawLine(x0,y0,xf,yf,i) {
  ctx.beginPath();
  ctx.lineWidth = 3;
  ctx.moveTo(x0,y0);
  ctx.lineTo(xf,yf);
  if (selectedLine == i) ctx.strokeStyle = "red";
  else ctx.strokeStyle = "#fff";
  ctx.stroke();
  lineX0 = x0;
  lineY0 = y0;
  lineXf = xf;
  lineYf = yf;
}

//start
drawCurrentCanvas();